
## Header: General Commands ##

# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# run the python program for hydrogen bonding interactions.
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3

# Loren Williams, Georgia Tech
# pymol script for A-Form RNA
## End Header ##



load ./files/24-mer_A-RNA.pdb, cartoon_1_RNA
load ./files/24-mer_A-RNA.pdb, stick_1_RNA
load ./files/24-mer_A-RNA.pdb, stick_2_RNA
load ./files/24-mer_A-RNA.pdb, space_1_RNA
load ./files/maj_gr_min_gr.pdb, maj_gr_min_gr

remove name H*

#-------- carton duplex_1
set cartoon_ring_mode=3, cartoon_1_RNA
hide everything, cartoon_1_RNA
set cartoon_tube_radius=0.4, cartoon_1_RNA
show cartoon, cartoon_1_RNA


#-------- Stick duplex_2
hide everything, stick_1_RNA
show stick, stick_1_RNA
remove stick_1_RNA and (name OP1,OP2,OP3)


#-------- Stick duplex_3
hide everything, stick_2_RNA
show stick, stick_2_RNA
h_add stick_2_RNA

#-------- Space fill duplex
hide everything, space_1_RNA
h_add space_1_RNA
show sphere, space_1_RNA

#-------- Color
color gray90, (name H*)
color wheat, (name C*)
color red, (name O*)
color blue, (name N*)
color yelloworange, (name P)



#---------------hydrogen bonds----------------

distance WC_Hbond, (name O2,N3,N4 and resn C and stick_1_RNA ), (name N2,N1,O6 and resn G and stick_1_RNA ), 3.1
distance WC_Hbond, (name N3,O4 and resn U and stick_1_RNA ), (name N1,N6 and resn A and stick_1_RNA ), 3.1
color black, WC_Hbond
hide labels, WC_Hbond
set dash_width, 3
set dash_gap, 0.4


#-------- Label the grooves
hide everything, maj_gr_min_gr 
label /maj_gr_min_gr//A/A`16/MA, "Major Groove"
label /maj_gr_min_gr//A/A`13/MI, "Minor Groove"
set label_size, -1
set label_font_id, 7
set label_color, deeppurple, maj_gr_min_gr and name MA
set label_color, forest, maj_gr_min_gr and name MI
set label_outline_color, black
set label_shadow_mode, 2


#-------- color the duplex bases

color red, (resn ADE or resn A) and (stick_1_RNA or cartoon_1_RNA)
color blue, (resn URA or resn U or resn THY or resn T) and (stick_1_RNA or cartoon_1_RNA)
color forest, (resn CYT or resn C) and (stick_1_RNA or cartoon_1_RNA)
color violetpurple, (resn GUA or resn G) and (stick_1_RNA or cartoon_1_RNA)



#-------- make an A-U base pair
create AU_base_pair, (stick_1_RNA and resi 13 and chain A) or (stick_1_RNA and resi 12 and chain B)
show sticks, AU_base_pair
remove name P+O1P+O2P and AU_base_pair
color wheat, (AU_base_pair and name C*)
color red, (AU_base_pair and name O*)
color blue, (AU_base_pair and name N*)
color white, (AU_base_pair and name H*)
dist hbond_AU, stick_1_RNA and resi 13 and chain A, stick_1_RNA and resi 12 and chain B, 3.4
color black, hbond_AU
set label_size, -0.8, hbond_AU


#-------- make a G-C base pair
create GC_base_pair,  (stick_1_RNA and resi 14 and chain A) or (stick_1_RNA and resi 11 and chain B)
show sticks, GC_base_pair
remove name P+O1P+O2P and GC_base_pair
color wheat, (GC_base_pair and name C*)
color red, (GC_base_pair and name O*)
color blue, (GC_base_pair and name N*)
color white, (GC_base_pair and name H*)
dist hbond_GC, (stick_1_RNA and resi 14 and chain A), (stick_1_RNA and resi 11 and chain B), 3.4
color black, hbond_GC
set label_size, -0.8, hbond_GC


disable all
enable cartoon_1_RNA
enable stick_1_RNA
#enable maj_groove
#enable min_groove
enable WC_hbond*

set sweep_angle = 3600
set sweep_mode = 0
set sweep_speed = 0.005

set_view (\
     0.955362618,    0.132604629,    0.263988405,\
     0.255207300,    0.079690233,   -0.963592052,\
    -0.148814499,    0.987956882,    0.042293422,\
    -0.000003239,    0.000002742, -103.912300110,\
     1.110138893,   -0.088923298,    0.582374036,\
  -1263.956420898, 1471.781127930,  -20.000000000 )
ray
#ray, 2000,2000